summaryrefslogtreecommitdiffstats
path: root/remoting/host/chromoting_host.h
diff options
context:
space:
mode:
authorhclam@chromium.org <hclam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-11-16 19:53:35 +0000
committerhclam@chromium.org <hclam@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2010-11-16 19:53:35 +0000
commit6fd3d6a1648a754d8023924074612d55c187b4cf (patch)
tree102ac605e52b8cf1a4e423b5403a0302a5ee9f76 /remoting/host/chromoting_host.h
parent3e4155c723ab73c8f754a82d81f0eb247c83536f (diff)
downloadchromium_src-6fd3d6a1648a754d8023924074612d55c187b4cf.zip
chromium_src-6fd3d6a1648a754d8023924074612d55c187b4cf.tar.gz
chromium_src-6fd3d6a1648a754d8023924074612d55c187b4cf.tar.bz2
Implement input stub in the host side for chromoting
Implement InputStub for the host. BUG=None TEST=None Review URL: http://codereview.chromium.org/4726003 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@66314 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'remoting/host/chromoting_host.h')
-rw-r--r--remoting/host/chromoting_host.h13
1 files changed, 5 insertions, 8 deletions
diff --git a/remoting/host/chromoting_host.h b/remoting/host/chromoting_host.h
index 6616c24..ab285ab 100644
--- a/remoting/host/chromoting_host.h
+++ b/remoting/host/chromoting_host.h
@@ -11,10 +11,10 @@
#include "remoting/base/encoder.h"
#include "remoting/host/access_verifier.h"
#include "remoting/host/capturer.h"
-#include "remoting/host/event_executor.h"
#include "remoting/host/heartbeat_sender.h"
#include "remoting/jingle_glue/jingle_client.h"
#include "remoting/jingle_glue/jingle_thread.h"
+#include "remoting/protocol/input_stub.h"
#include "remoting/protocol/session_manager.h"
#include "remoting/protocol/connection_to_client.h"
@@ -30,7 +30,6 @@ class SessionConfig;
class Capturer;
class ChromotingHostContext;
class Encoder;
-class EventExecutor;
class MutableHostConfig;
class SessionManager;
@@ -46,7 +45,7 @@ class SessionManager;
// a ConnectionToClient object that wraps around linjingle for transport.
// Also create a SessionManager with appropriate Encoder and Capturer and
// add the ConnectionToClient to this SessionManager for transporting the
// screen captures. A EventExecutor is created and registered with the
// ConnectionToClient to receive mouse / keyboard events from the remote
// client.
// This is also the right time to create multiple threads to host
@@ -64,7 +63,7 @@ class ChromotingHost : public base::RefCountedThreadSafe<ChromotingHost>,
public JingleClient::Callback {
public:
ChromotingHost(ChromotingHostContext* context, MutableHostConfig* config,
- Capturer* capturer, EventExecutor* executor);
+ Capturer* capturer, protocol::InputStub* input_stub);
virtual ~ChromotingHost();
// Asynchronously start the host process.
@@ -89,8 +88,6 @@ class ChromotingHost : public base::RefCountedThreadSafe<ChromotingHost>,
////////////////////////////////////////////////////////////////////////////
// protocol::ConnectionToClient::EventHandler implementations
- virtual void HandleMessage(protocol::ConnectionToClient* client,
- ChromotingClientMessage* message);
virtual void OnConnectionOpened(protocol::ConnectionToClient* client);
virtual void OnConnectionClosed(protocol::ConnectionToClient* client);
virtual void OnConnectionFailed(protocol::ConnectionToClient* client);
@@ -133,8 +130,8 @@ class ChromotingHost : public base::RefCountedThreadSafe<ChromotingHost>,
// constructed this is set to NULL.
scoped_ptr<Encoder> encoder_;
- // EventExecutor executes input events received from the client.
- scoped_ptr<EventExecutor> executor_;
+ // InputStub in the host executes input events received from the client.
+ scoped_ptr<protocol::InputStub> input_stub_;
// The libjingle client. This is used to connect to the talk network to
// receive connection requests from chromoting client.
@@ -46,7 +45,7 @@ class SessionManager;
// Also create a SessionManager with appropriate Encoder and Capturer and
// add the ConnectionToClient to this SessionManager for transporting the
-// screen captures. A EventExecutor is created and registered with the
+// screen captures. An InputStub is created and registered with the
// ConnectionToClient to receive mouse / keyboard events from the remote
// client.